/*

    File: ext2_inc.h

    Copyright (C) 2007 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */
#ifndef _EXT2_INC_H
#define _EXT2_INC_H

#if defined(DISABLED_FOR_FRAMAC)
#undef HAVE_LIBEXT2FS
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if defined(HAVE_LIBEXT2FS)
struct ext2_dir_struct {
	file_info_t *dir_list;
	ext2_filsys current_fs;
	int flags;
	dir_data_t *dir_data;
};
#endif

#ifdef __cplusplus
} /* closing brace for extern "C" */
#endif
#endif
